@@ -1,32 +1,25 @@
 use std::ptr::null_mut;
-use { ffi, Bitmap };
+use {ffi, Bitmap};
 
 pub struct BitmapGlyph {
     library_raw: ffi::FT_Library,
-    raw: ffi::FT_BitmapGlyph
+    raw: ffi::FT_BitmapGlyph,
 }
 
 impl BitmapGlyph {
     pub unsafe fn from_raw(library_raw: ffi::FT_Library, raw: ffi::FT_BitmapGlyph) -> Self {
         ffi::FT_Reference_Library(library_raw);
-        BitmapGlyph {
-            library_raw: library_raw,
-            raw: raw
-        }
+        BitmapGlyph { library_raw, raw }
     }
 
     #[inline(always)]
     pub fn left(&self) -> i32 {
-        unsafe {
-            (*self.raw).left
-        }
+        unsafe { (*self.raw).left }
     }
 
     #[inline(always)]
     pub fn top(&self) -> i32 {
-        unsafe {
-            (*self.raw).top
-        }
+        unsafe { (*self.raw).top }
     }
 
     #[inline(always)]
@@ -36,9 +29,7 @@ impl BitmapGlyph {
 
     #[inline(always)]
     pub fn raw(&self) -> &ffi::FT_BitmapGlyphRec {
-        unsafe {
-            &*self.raw
-        }
+        unsafe { &*self.raw }
     }
 }
 
@@ -46,9 +37,7 @@ impl Clone for BitmapGlyph {
     fn clone(&self) -> Self {
         let mut target = null_mut();
 
-        let err = unsafe {
-            ffi::FT_Glyph_Copy(self.raw as ffi::FT_Glyph, &mut target)
-        };
+        let err = unsafe { ffi::FT_Glyph_Copy(self.raw as ffi::FT_Glyph, &mut target) };
         if err == ffi::FT_Err_Ok {
             unsafe { BitmapGlyph::from_raw(self.library_raw, target as ffi::FT_BitmapGlyph) }
         } else {
@@ -67,4 +56,4 @@ impl Drop for BitmapGlyph {
             panic!("Failed to drop library")
         }
     }
-}
\ No newline at end of file
+}
